@@ -54,7 +54,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'            => 'Časové pásmo návštěvníků',
   'SYSTEM_TIMEZONE_EXPLAIN'         => 'Nepřihlášení uživatelé uvidí časy na fóru v tomto časovém pásmo. Registrovani uživatele si jej mohou změnit při registraci a později ve svém panelu nastavení.',
 	'WARNINGS_EXPIRE'				=> 'Doba platnosti varování',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Počet dní, které musí uplynout, než se varování automaticky odstraní z uživatelského profilu.',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Počet dní, které musí uplynout, než se varování automaticky odstraní z uživatelského profilu. Pro nastavení trvalého varování zadejte 0.',
 ));
 
 // Board Features
@@ -175,7 +175,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'								=> 'Maximální počet odkazů na příspěvek',
 	'MAX_POST_URLS_EXPLAIN'				=> 'Nejvyšší povolený počet odkazů v&nbsp;příspěvku. Nastavte na 0 pro neomezený počet.',
 	'MIN_CHAR_LIMIT'							=> 'Minimum znaků ve zprávě',
-	'MIN_CHAR_LIMIT_EXPLAIN'			=> 'Uživatelé nesmí zadat méně než tento počet znaků ve zprávě, aby byla odeslána. Toto nastavení je vhodné k omezení spamových a jednoslovných zpráv.',
+	'MIN_CHAR_LIMIT_EXPLAIN'			=> 'Uživatelé nesmí zadat méně než tento počet znaků ve zprávě, aby byla odeslána. Toto nastavení je vhodné k omezení spamových a jednoslovných zpráv. Minimální hodnota nastavení je 1 znak.',
 	'POSTING'											=> 'Přispívání',
 	'POSTS_PER_PAGE'							=> 'Počet příspěvků na stránku',
 	'QUOTE_DEPTH_LIMIT'						=> 'Maximum vnořených citací',
@@ -556,4 +556,4 @@ $lang = array_merge($lang, array(
 	'JAB_USERNAME_EXPLAIN'		=> 'Vložte uživatelské jméno nebo platné Jabber ID. Tato položka nebude kontrolována, jestli je platná. Pokud uvedete pouze uživatelské jméno (část před zavináčem), vaše Jabber ID bude toto jméno dohromady se serverem, který jste uvedli výše. Další možnost je uvést kompletní JID, např. uzivatel@jabber.org',
 ));
 
-?>
+?>
\ No newline at end of file
