@@ -330,6 +330,16 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'	=> 'Databázový server',
 	'DATABASE_SIZE'			=> 'Velikost databáze',
 
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'Funkce zatížení není správně nastavena.',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> musí být nastaveno na 0 nebo 4. Aktuální hodnoty můžete zkontrolovat na stránce s <samp>PHP informacemi</samp>.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Transpantní kódování znaků není správně nastaveno.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> musí být nastaveno na 0. Aktuální hodnoty můžete zkontrolovat na stránce s <samp>PHP informacemi</samp>.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'Konverze vstupní HTTP znaků není správně nastavena.',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> musí být nastaven na <samp>pass</samp>. Aktuální hodnoty můžete zkontrolovat na stránce s <samp>PHP informacemi</samp>.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'Konverze výstupních HTTP znaků není správně nastavena.',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> musí být nastaven na <samp>pass</samp>. Aktuální hodnoty můžete zkontrolovat na stránce s <samp>PHP informacemi</samp>.',
+  
 	'FILES_PER_DAY'		=> 'Příloh za den',
 	'FORUM_STATS'		=> 'Statistiky fóra',
 
@@ -742,4 +752,4 @@ $lang = array_merge($lang, array(
 	'LOG_WORD_EDIT'			=> '<strong>Upraveno cenzurované slovo</strong><br />» %s',
 ));
 
-?>
+?>
\ No newline at end of file
