@@ -166,6 +166,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Při psaní nové zprávy musíte uvést předmět.',
 	'ENABLED'											=> 'Povoleno',
 	'ENCLOSURE'										=> 'Uzavření',
+  'ENTER_USERNAME'					=> 'Zadejte uživatelské jméno',
 	'ERR_CHANGING_DIRECTORY'			=> 'Nelze změnit adresář.',
 	'ERR_CONNECTING_SERVER'				=> 'Chyba při připojení k&nbsp;serveru.',
 	'ERR_JAB_AUTH'								=> 'Nelze se přihlásit k&nbsp;Jabber serveru.',
@@ -201,7 +202,8 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'	=> 'Prosím, klikněte pro zobrazení pravidel fóra',
 	'FROM'							=> 'od',
 	'FSOCK_DISABLED'		=> 'Operace nemohla být dokončena, protože funkce <var>fsockopen</var> je zakázána nebo dotazovaný server nebyl nalezen.',
-
+  'FSOCK_TIMEOUT'			=> 'Časový limit pro čtení z proudu sítě vypršel.'
+  
 	'FTP_FSOCK_HOST'							=> 'FTP server',
 	'FTP_FSOCK_HOST_EXPLAIN'			=> 'FTP server, kterým se připojujete na vaši stránku.',
 	'FTP_FSOCK_PASSWORD'					=> 'Heslo k&nbsp;FTP',
@@ -656,13 +658,17 @@ $lang = array_merge($lang, array(
 	'UNREAD_PM'								=> '<strong>%d</strong> nepřečtená zpráva',
 	'UNREAD_PMS'							=> '<strong>%d</strong> nepřečtených zpráv',
 	'UNREAD_POST'         => 'Nový příspěvek',
-    'UNREAD_POSTS'         => 'Nové příspěvky',
+  'UNREAD_POSTS'         => 'Nové příspěvky',
+  'UNWATCH_FORUM_CONFIRM'		=> 'Opravdu chcete přestat sledovat toto fórum?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Opravdu chcete přestat sledovat fórum “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Opravdu chcete přestat sledovat toto téma?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Opravdu chcete přestat sledovat téma “%s”?',
 	'UNWATCHED_FORUMS'				=> 'Přestali jste sledovat zvolená fóra.',
 	'UNWATCHED_TOPICS'				=> 'Přestali jste sledovat zvolená témata.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Přestali jste sledovat zvolené příspěvky.',
 	'UPDATE'									=> 'Aktualizovat',
 	'UPLOAD_IN_PROGRESS'			=> 'Právě probíhá nahrávání souboru',
-	'URL_REDIRECT'			=> 'Pokud váš prohlížeč nepodporuje přesměrování přes meta tagy, %spřejděte na další stránku%s.',
+	'URL_REDIRECT'			=> 'Pokud váš prohlížeč nepodporuje přesměrování přes meta tagy, %s přejděte na další stránku%s.',
 	'USERGROUPS'				=> 'Skupiny',
 	'USERNAME'					=> 'Uživatelské jméno',
 	'USERNAMES'					=> 'Uživatelská jména',
@@ -704,6 +710,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'				=> 'Varování',
 	'WARN_USER'				=> 'Varovat uživatele',
+  'WATCH_FORUM_CONFIRM'	=> 'Opravdu chcete sledovat toto fórum?',
+	'WATCH_FORUM_DETAILED'	=> 'Opravdu chcete sledovat fórum â€ś%sâ€ť?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Opravdu chcete sledovat toto téma?',
+	'WATCH_TOPIC_DETAILED'	=> 'Opravdu chcete sledovat téma â€ś%sâ€ť?',
 	'WELCOME_SUBJECT'	=> 'Vítejte na fóru %s',
 	'WEBSITE'					=> 'WWW',
 	'WHOIS'						=> 'Whois',
@@ -884,4 +894,4 @@ $lang = array_merge($lang, array(
 
 ));
 
-?>
+?>
\ No newline at end of file
