@@ -62,7 +62,7 @@ $help = array(
 	),
 	array(
 		0 => 'V minulosti jsem se zaregistroval, ovšem nyní se nemohu přihlásit?!',
-		1 => 'Nejpravděpodobnější důvody: zadali jste chybné uživatelské jméno nebo heslo (zkontrolujte e-mail, který jste obdrželi při registraci) nebo administrátor z nějakého důvodu smazal váš účet. Pokud je to ten druhý případ, pak jste možná nevložili žádný příspěvek. Je to obvyklé, že se pravidelně odstraňují uživatelé, kteří ničím nepřispěli, aby se zmenšila velikost databáze. Zkuste se zaregistrovat znovu a zapojte se do diskuzí.'
+		1 => 'Nejspíše administrátor z nějakého důvodu smazal váš účet. To mohlo být z důvodu, že jste možná nevložili žádný příspěvek. Je to obvyklé, že se pravidelně odstraňují uživatelé, kteří ničím nepřispěli, aby se zmenšila velikost databáze. Zkuste se zaregistrovat znovu a zapojte se do diskuzí.'
 	),
 	array(
 		0 => 'Co znamená COPPA?',
@@ -343,4 +343,4 @@ $help = array(
 	)
 );
 
-?>
+?>
\ No newline at end of file
