@@ -141,6 +141,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'Nynější obrázek',
 	'CURRENT_PASSWORD'			=> 'Nynější heslo',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'Pokud chcete změnit heslo nebo e-mailovou adresu, zadejte vaše nynější heslo.',
+  'CUR_PASSWORD_EMPTY'		=> 'Nezadali jste současné heslo.',
 	'CUR_PASSWORD_ERROR'		=> 'Zadali jste neplatné heslo.',
 	'CUSTOM_DATEFORMAT'			=> 'Vlastní…',
 		
@@ -270,10 +271,12 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'				=> 'Nastal problém při přesouvání zpráv do nové složky, bylo přesunuto pouze %1d z %2d zpráv.',
 	'MOVE_TO_FOLDER'			=> 'Přesunout do adresáře',
 	'MOVE_UP'					=> 'Přesunout nahoru',
-	
+
+  'NEW_EMAIL_CONFIRM_EMPTY'		=> 'Nezadali jste podruhé vaší e-mailovou adresu pro její potvrzení.',	
 	'NEW_EMAIL_ERROR'			=> 'E-mailová adresa nesouhlasí.',
 	'NEW_FOLDER_NAME'			=> 'Název nového adresáře',
 	'NEW_PASSWORD'				=> 'Heslo',
+  'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Nezadali jste podruhé vaše heslo pro jeho potvrzení.',
 	'NEW_PASSWORD_ERROR'		=> 'Heslo musí odpovídat.',
 	'NOTIFY_METHOD'				=> 'Způsob oznámení',
 	'NOTIFY_METHOD_BOTH'		=> 'Oba způsoby',
@@ -558,4 +561,4 @@ $lang = array_merge($lang, array(
 	'NO_NONMEMBER'	=> 'Žádné skupiny bez členství',
 ));
 
-?>
+?>
\ No newline at end of file
